@@ -3,7 +3,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.1.0 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.1.2 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -480,7 +480,11 @@ def main():
                 skipped += 1
                 continue
             checked += 1
-            version = entry.get_latest()
+            try:
+                version = entry.get_latest()
+            except Exception as e:
+                logging.error('unable to get latest', e)
+                continue
             if version:
                 new += 1
             if version and version.diff and 'twitter' in f:
